@@ -2,7 +2,6 @@
 App configuration for eox_hooks.
 """
 
-from __future__ import unicode_literals
 
 from importlib import import_module
 
@@ -68,20 +67,32 @@ class EoxHooksConfig(AppConfig):
                 'receivers': [
                     {
                         'receiver_func_name': 'hooks_handler',
-                        'signal_path': get_signal_module("pre_enrollment"),
+                        'signal_path': get_signal_module('pre_enrollment'),
                         'dispatch_uid': 'eox-hooks:pre_enrollment',
                     },
                     {
                         'receiver_func_name': 'hooks_handler',
-                        'signal_path': get_signal_module("post_certificate_creation"),
-                        'dispatch_uid': "eox-hooks:post_certificate_creation",
+                        'signal_path': get_signal_module('post_certificate_creation'),
+                        'dispatch_uid': 'eox-hooks:post_certificate_creation',
                     },
                     {
                         'receiver_func_name': 'hooks_handler',
-                        'signal_path': get_signal_module("post_register"),
-                        'dispatch_uid': "eox-hooks:post_register",
+                        'signal_path': get_signal_module('post_register'),
+                        'dispatch_uid': 'eox-hooks:post_register',
+                    },
+                    {
+                        'receiver_func_name': 'hooks_handler',
+                        'signal_path': get_signal_module('post_enrollment'),
+                        'dispatch_uid': 'eox-hooks:post_enrollment',
                     },
                 ],
             }
         },
     }
+
+    # pylint: disable=import-outside-toplevel
+    def ready(self):
+        """
+        Make sure tasks are registered.
+        """
+        from eox_hooks import tasks  # pylint: disable=unused-import
