@@ -7,7 +7,8 @@ from django.conf import settings
 def get_openedx_certificate_model():
     """Return the GeneratedCertificate model class when called during runtime"""
     if not getattr(settings, "EOX_HOOKS_TEST_ENVIRONMENT", False):
-        from lms.djangoapps.certificates.models import GeneratedCertificate  # pylint: disable=import-error
+        # pylint: disable=import-error,import-outside-toplevel
+        from lms.djangoapps.certificates.models import GeneratedCertificate
 
         return GeneratedCertificate
     # Return None when testing to avoid ImportError
@@ -17,7 +18,7 @@ def get_openedx_certificate_model():
 def get_openedx_user_profile_model():
     """Return the UserProfile model class when called during runtime"""
     if not getattr(settings, "EOX_HOOKS_TEST_ENVIRONMENT", False):
-        from student.models import UserProfile  # pylint: disable=import-error
+        from student.models import UserProfile  # pylint: disable=import-error,import-outside-toplevel
 
         return UserProfile
     # Return None when testing to avoid ImportError
